<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>Arqiver::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="148"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Arqiver::Backend</name>
    <message>
        <location filename="../../backends.cpp" line="849"/>
        <source>This file is a link but its target does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1273"/>
        <location filename="../../backends.cpp" line="1305"/>
        <location filename="../../backends.cpp" line="1349"/>
        <source>Could not read archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1308"/>
        <location filename="../../backends.cpp" line="1354"/>
        <source>Archive Loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1315"/>
        <location filename="../../backends.cpp" line="1402"/>
        <source>Modification Finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1336"/>
        <location filename="../../backends.cpp" line="1371"/>
        <source>Extraction Finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1339"/>
        <location filename="../../backends.cpp" line="1390"/>
        <source>Extraction Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1487"/>
        <source>%1 is missing from your system.
Please install it for this kind of archive!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Arqiver::LineEdit</name>
    <message>
        <location filename="../../lineedit.h" line="33"/>
        <source>You could type inside the main view.
Clear text with the Escape key.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Arqiver::PrefDialog</name>
    <message>
        <location filename="../../pref.ui" line="14"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="50"/>
        <source>Start with this size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="118"/>
        <source>Use system icons where possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="125"/>
        <source>Show prompt on removing items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="132"/>
        <source>If this is unchecked, only the top level directories will be expanded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="135"/>
        <source>Expand all directories when opening archives</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="147"/>
        <location filename="../../pref.ui" line="160"/>
        <source>Leave empty for the default.

Warning: Arqiver will not work if the
binary does not belong to libarchive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="153"/>
        <source>libarchive binary:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="38"/>
        <source>Remember window &amp;size on closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="93"/>
        <source>Size of view icons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="56"/>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="178"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="235"/>
        <source>Select libarchive binary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Arqiver::mainWin</name>
    <message>
        <location filename="../../mainWin.ui" line="53"/>
        <source>Archive:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="106"/>
        <source>Filter Files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="129"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="140"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="155"/>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="166"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="204"/>
        <source>&amp;Open Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="207"/>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="212"/>
        <source>&amp;New Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="215"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="220"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="223"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="228"/>
        <source>Add File(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="233"/>
        <source>Remove File(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="238"/>
        <source>Extract All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="241"/>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="246"/>
        <source>Add Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="251"/>
        <source>Extract Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="256"/>
        <source>Set Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="261"/>
        <source>E&amp;xpand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="264"/>
        <source>Ctrl+Shift+Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="269"/>
        <source>Collap&amp;se</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="272"/>
        <source>Ctrl+Shift+Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="277"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="282"/>
        <source>&amp;Copy Current Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="287"/>
        <source>&amp;Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="292"/>
        <source>Stop &amp;Process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="295"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="305"/>
        <source>Update Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="149"/>
        <source>Root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="254"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="325"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="325"/>
        <source>MimeType</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="325"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="554"/>
        <location filename="../../mainWin.cpp" line="839"/>
        <location filename="../../mainWin.cpp" line="882"/>
        <source>Opening Archive...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="768"/>
        <source>Create Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="465"/>
        <location filename="../../mainWin.cpp" line="794"/>
        <location filename="../../mainWin.cpp" line="996"/>
        <location filename="../../mainWin.cpp" line="1307"/>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="795"/>
        <source>The following archive already exists:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="797"/>
        <source>Do you want to replace it?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="831"/>
        <source>Open Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="897"/>
        <location filename="../../mainWin.cpp" line="904"/>
        <location filename="../../mainWin.cpp" line="945"/>
        <source>Add to Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="940"/>
        <location filename="../../mainWin.cpp" line="971"/>
        <location filename="../../mainWin.cpp" line="1254"/>
        <location filename="../../mainWin.cpp" line="1260"/>
        <source>Adding Items...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="997"/>
        <source>Do you want to remove the selected item(s)?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1016"/>
        <source>Removing Items...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1217"/>
        <location filename="../../mainWin.cpp" line="1232"/>
        <location filename="../../mainWin.cpp" line="1322"/>
        <location filename="../../mainWin.cpp" line="1336"/>
        <source>Extracting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1060"/>
        <source>Copy Archive Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="466"/>
        <source>Some files have been modified.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="467"/>
        <source>Do you want to ignore the changes?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="628"/>
        <source>All Types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="638"/>
        <location filename="../../mainWin.cpp" line="662"/>
        <source>Uncompressed Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="639"/>
        <location filename="../../mainWin.cpp" line="663"/>
        <source>GZip Compressed Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="640"/>
        <location filename="../../mainWin.cpp" line="664"/>
        <location filename="../../mainWin.cpp" line="665"/>
        <source>BZip Compressed Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="641"/>
        <location filename="../../mainWin.cpp" line="666"/>
        <source>BZip2 Compressed Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="642"/>
        <location filename="../../mainWin.cpp" line="674"/>
        <source>LMZA Compressed Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="643"/>
        <location filename="../../mainWin.cpp" line="671"/>
        <source>XZ Compressed Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="644"/>
        <location filename="../../mainWin.cpp" line="675"/>
        <source>Zstandard Compressed Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="645"/>
        <location filename="../../mainWin.cpp" line="677"/>
        <source>CPIO Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="647"/>
        <location filename="../../mainWin.cpp" line="679"/>
        <source>AR Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="649"/>
        <location filename="../../mainWin.cpp" line="681"/>
        <source>Zip Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="650"/>
        <location filename="../../mainWin.cpp" line="683"/>
        <source>Gzip Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="651"/>
        <location filename="../../mainWin.cpp" line="682"/>
        <source>7-Zip Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="667"/>
        <location filename="../../mainWin.cpp" line="668"/>
        <source>READ-ONLY: BZip Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="669"/>
        <source>READ-ONLY: BZip2 Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="670"/>
        <source>READ-ONLY: BZip2 Compressed PDF Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="672"/>
        <source>READ-ONLY: XZ archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="673"/>
        <source>READ-ONLY: XZ Compressed PDF Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="676"/>
        <source>READ-ONLY: Zstandard archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="684"/>
        <source>Gzip Compressed PDF Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="685"/>
        <source>READ-ONLY: Compressed SVG Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="686"/>
        <location filename="../../mainWin.cpp" line="687"/>
        <location filename="../../mainWin.cpp" line="688"/>
        <location filename="../../mainWin.cpp" line="689"/>
        <source>READ-ONLY: ISO Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="690"/>
        <source>READ-ONLY: XAR Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="691"/>
        <source>READ-ONLY: Java Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="692"/>
        <source>READ-ONLY: Debian Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="693"/>
        <location filename="../../mainWin.cpp" line="694"/>
        <source>READ-ONLY: RedHat Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="695"/>
        <location filename="../../mainWin.cpp" line="696"/>
        <location filename="../../mainWin.cpp" line="697"/>
        <source>READ-ONLY: MS Windows Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="698"/>
        <source>READ-ONLY: MS Windows Installer Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="699"/>
        <source>READ-ONLY: MS Windows Cabinet Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="700"/>
        <source>READ-ONLY: ACE archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="701"/>
        <source>READ-ONLY: Android Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="702"/>
        <source>READ-ONLY: RAR Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="703"/>
        <source>READ-ONLY: AppImage application bundle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="704"/>
        <source>READ-ONLY: VirtualBox Extension Pack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="713"/>
        <source>All Known Types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="718"/>
        <source>Show All Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1070"/>
        <source>Open Containing Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="300"/>
        <source>View Current Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1113"/>
        <location filename="../../mainWin.cpp" line="1121"/>
        <source>Enter Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1129"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1134"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1138"/>
        <source>Encrypt the file list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1139"/>
        <source>This will take effect after files/folders are added.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1210"/>
        <location filename="../../mainWin.cpp" line="1286"/>
        <source>Extract Into Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1308"/>
        <source>Some files will be overwritten.
Do you want to continue?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1442"/>
        <source>Link To: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1716"/>
        <source>Could not read archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1789"/>
        <source>A simple Qt archive manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1790"/>
        <source>based on libarchive, gzip and 7z</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1791"/>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1792"/>
        <source>aka.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1793"/>
        <location filename="../../mainWin.cpp" line="1794"/>
        <source>About Arqiver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1793"/>
        <source>Translators</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
